KernelObject

Enum KernelObject 

pub enum KernelObject {
    File(Arc<dyn FileObject>),
    Pipe(Arc<dyn PipeObject>),
    Counter(Arc<dyn CounterObject>),
    EventChannel(Arc<EventChannelObject>),
    EventSubscription(Arc<EventSubscriptionObject>),
    Socket(Arc<dyn SocketObject>),
    SharedMemory(Arc<dyn SharedMemoryObject>),
}
Unified representation of all kernel-managed resources

Note: Debug is not implemented for KernelObject because it contains trait objects that may not implement Debug. Use introspection methods instead.

Variants



File(Arc<dyn FileObject>)



Pipe(Arc<dyn PipeObject>)



Counter(Arc<dyn CounterObject>)



EventChannel(Arc<EventChannelObject>)



EventSubscription(Arc<EventSubscriptionObject>)



Socket(Arc<dyn SocketObject>)



SharedMemory(Arc<dyn SharedMemoryObject>)

Implementations

Source

impl KernelObject

pub fn from_file_object(file_object: Arc<dyn FileObject>) -> Self

Create a KernelObject from a FileObject

pub fn from_pipe_object(pipe_object: Arc<dyn PipeObject>) -> Self

Create a KernelObject from a PipeObject

pub fn from_event_channel_object(event_channel: Arc<EventChannelObject>) -> Self

Create a KernelObject from an EventChannelObject

pub fn from_event_subscription( event_subscription: Arc<EventSubscriptionObject>, ) -> Self

Create a KernelObject from an EventSubscriptionObject

pub fn from_socket_object(socket: Arc<dyn SocketObject>) -> Self

Create a KernelObject from a SocketObject

pub fn from_shared_memory_object( shared_memory: Arc<dyn SharedMemoryObject>, ) -> Self

Create a KernelObject from a SharedMemoryObject

pub fn from_counter(counter: Arc<Counter>) -> Self

Create a KernelObject from a Counter

pub fn as_stream(&self) -> Option<&dyn StreamOps>

Try to get StreamOps capability

pub fn as_stream_ipc(&self) -> Option<&dyn StreamIpcOps>

Try to get StreamIpcOps capability for IPC stream operations

pub fn as_file(&self) -> Option<&dyn FileObject>

Try to get FileObject that provides file-like operations and stream capabilities

pub fn as_pipe(&self) -> Option<&dyn PipeObject>

Try to get PipeObject that provides pipe-specific operations

pub fn as_socket(&self) -> Option<&dyn SocketObject>

Try to get SocketObject that provides socket-specific operations

pub fn as_shared_memory(&self) -> Option<&dyn SharedMemoryObject>

Try to get SharedMemoryObject that provides shared memory operations

pub fn as_cloneable(&self) -> Option<&dyn CloneOps>

Try to get CloneOps capability

pub fn as_control(&self) -> Option<&dyn ControlOps>

Try to get ControlOps capability

pub fn as_memory_mappable(&self) -> Option<&dyn MemoryMappingOps>

Try to get MemoryMappingOps capability

pub fn as_memory_mappable_weak(&self) -> Option<Weak<dyn MemoryMappingOps>>

Try to get weak reference to MemoryMappingOps capability

pub fn as_event_channel(&self) -> Option<&EventChannelObject>

Try to get EventChannelObject

pub fn as_event_subscription(&self) -> Option<&EventSubscriptionObject>

Try to get EventSubscriptionObject

pub fn as_counter(&self) -> Option<&dyn CounterObject>

Try to get CounterObject

pub fn as_selectable(&self) -> Option<&dyn Selectable>

Try to get Selectable capability for pselect/select readiness

pub fn arc_clone(&self) -> Self

Clone the KernelObject at the Arc level only (no state changes).

Unlike the Clone trait implementation which may use custom_clone() for objects like Pipes (incrementing reader/writer counts), this method performs a simple Arc::clone() that only increments the Arc reference count without modifying the underlying object state.

Use this when you need a copy of the KernelObject for temporary access without intending to create a new logical file descriptor (dup semantics).